import { BulkUpdateService } from "../types/bulk-update-service-type";
import { DeleteService } from "../types/delete-service-type";
import { CreateService } from "../types/create-service-type";
import { ListService } from "../types/list-service-type";
import { GetService } from "../types/get-service-type";
import { NestedCreateService } from "../types/nested-create-service-type";
import { NestedListService } from "../types/nested-list-service-type";
import { UpdateService } from "../types/update-service-type";
/**
 * Factory to encapsulate common service function logic
 */
declare const ServiceFactory: {
    /**
     * Creates a conventional Service Update function for an Array of the supplied resource type
     * @param recordType
     * @param resourceEndpoint
     */
    bulkUpdate<TRecord extends any, TPathParams extends any>(recordType: new () => TRecord, resourceEndpoint: string): BulkUpdateService<TRecord, TPathParams>;
    /**
     * Creates conventional Service Create function for the supplied resource type
     *
     * ### Recommendation
     * Use `nestedCreate` when route is nested!
     *
     * @param recordType
     * @param baseEndpoint
     */
    create<TRecord_1 extends any>(recordType: new () => TRecord_1, baseEndpoint: string): CreateService<TRecord_1>;
    /**
     * Creates conventional Service Delete function for the supplied resource type
     * @param recordType
     * @param resourceEndpoint
     */
    delete(resourceEndpoint: string): DeleteService;
    /**
     * Creates conventional Service Get function for the supplied resource type
     * @param recordType
     * @param resourceEndpoint
     */
    get<TRecord_2, TPathParams_1, TQueryParams = undefined>(recordType: new () => TRecord_2, resourceEndpoint: string): GetService<TRecord_2, TPathParams_1, TQueryParams>;
    /**
     * Creates conventional Service List function for the supplied resource type
     *
     * ### Recommendation
     * Use `nestedList` when route is nested!
     *
     * @param recordType
     * @param baseEndpoint
     */
    list<TRecord_3, TQueryParams_1>(recordType: new () => TRecord_3, baseEndpoint: string): ListService<TRecord_3, TQueryParams_1>;
    /**
     * Creates conventional Service Create function for the supplied resource type
     * when the resource is nested
     * @param recordType
     * @param baseEndpoint
     */
    nestedCreate<TRecord_4 extends any, TPathParams_2>(recordType: new () => TRecord_4, baseEndpoint: string): NestedCreateService<TRecord_4, TPathParams_2>;
    /**
     * Creates conventional Service List function for the supplied resource type
     * @param recordType
     * @param baseEndpoint
     */
    nestedList<TRecord_5, TPathParams_3, TQueryParams_2>(recordType: new () => TRecord_5, baseEndpoint: string): NestedListService<TRecord_5, TPathParams_3, TQueryParams_2>;
    /**
     * Creates conventional Service Update function for the supplied resource type
     * @param recordType
     * @param resourceEndpoint
     */
    update<TRecord_6 extends any, TPathParams_4 extends any>(recordType: new () => TRecord_6, resourceEndpoint: string): UpdateService<TRecord_6, TPathParams_4>;
};
export { ServiceFactory };
